function [out]=funcpolefem(data)
% Computation of the solution of the free Schroedinger equation
% by Crank-Nicolson scheme with finite element method
% with Absorbing Boundary conditions : Pole Condition

% data is a cell
%  |
%  |--- data.a
%  |--- data.b
%  |--- data.sigma
%  |--- data.xc
%  |--- data.x0
%  |--- data.x1
%  |--- data.N
%  |--- data.tfinal
%  |--- data.dt
%  |--- data.k0  
%  |--- data.m
%  |--- data.initDatum
%  |--- data.axe1  : where to plot |u|
%  |--- data.axe2  : where to plot contour of log10|u|
%  |--- data.txtiter    : handle on textiter
%  |--- data.txtnbiter  : handle on textnbiter


% Setting default values
if ~isfield(data,'PlotFlag')
  data.PlotFlag = logical(1);
end
if ~isfield(data,'ReturnFlag')
  data.ReturnFlag = 1
end
% Data
a=data.a;
b=data.b;
savenb=data.savenb;

sigma=data.sigma;
xc=data.xc;
% Wave number
k0=data.k0;

% Computational domain : [x0,x1]
x0=data.x0;
x1=data.x1;
N=data.N;N=N+(N-1);
geo.x = linspace(x0,x1,N);
x = geo.x.'; p=geo.x; np = length(p); % point list
e = [[1:np-2];[2:np-1];[3:np]]; %element list
bd = [1 np];              % Boundary

dx = x(3)-x(1);

% Pole Condition parameters
M_Left =  data.m;
M_Right = data.m;
sigma0 = -1+i;

% Final time of computation
% dt : time step
% niter : number of iterations
tfinal=data.tfinal;
dt=data.dt;
niter=ceil(tfinal/dt);
if data.PlotFlag
  set(data.txtnbiter,'String',num2str(niter));  
end

%--------------------------------------------------------------
%--------------------------------------------------------------
SysMat = getSysMatpolefem2(p,e,bd,a,b,M_Left,M_Right,sigma0);
P_PD = SysMat.P_PD;

AA = -i/dt*SysMat.M - 1/2*SysMat.A;
BB = -i/dt*SysMat.M + 1/2*SysMat.A;

%[L, U, P, Q] = lu(AA);
%[L,U] = lu(AA);
[LA,UA,pA,qA] = lu(AA,'vector');
% Initial datum
u_n_PD = eval(data.initDatum);  
% try
%   V = potential_func(data.xc);
%   a = data.a;
%   b = data.b;
%   xc = data.xc;
%   k0 = data.k0;
%   sigma = data.sigma;
%   t = 0;
%   u_n_PD = eval(data.exactCpot); 
% catch
%    warning('Using initDatum') 
% end
u_n = P_PD * u_n_PD;

sav=1;
% pl : used to store |u^n|
pl=zeros(niter/savenb,N);
pl2=pl;
pl(1,:)=u_n_PD.';
tl=zeros(niter/savenb,1);
tl(1)=0;
MaxV=max(potential_func(x));
if (MaxV==0)
  MaxV=1;
end
%--------------------------------------------------------------
% Iterations
for k=1:niter,
  
  %u_n1 = Q*(U\(L\(P*(BB*u_n))));
  rhs = BB*u_n;
  u_n(qA,:)= UA\(LA\rhs(pA,:));
%   y = L\(BB*u_n);
%   u_n = U\y;
  %u_n = u_n1;
%      figure(11)
%      plot(x,abs(P_PD.'*u_n),'k:',x,real(P_PD.'*u_n),'m:',x,imag(P_PD.'*u_n),'c:',x,potential_func(x)/MaxV,'r:'); 
%      drawnow; pause(0.1)
  
% Display
  if rem(k,savenb)==0
%      figure(10)
%      plot(x,abs(P_PD.'*u_n),'k:',x,real(P_PD.'*u_n),'m:',x,imag(P_PD.'*u_n),'c:',x,potential_func(x)/MaxV,'r:'); hold on
%      drawnow; pause(0.1)
    sav=sav+1;
    pl(sav,:)=(P_PD.'*u_n).';
    tl(sav)=k*dt;
    if data.PlotFlag
      plot(x,abs(P_PD.'*u_n),x,potential_func(x)/MaxV,'r:','parent',data.axe1);axis(data.axe1,[x0 x1 0 1]);drawnow;
      set(data.txtiter,'String',num2str(k));
      if rem(sav,20)==0
	pl2(1:sav,:)=log10(abs(pl(1:sav,:)));
	contourf(x,tl(1:sav),pl2(1:sav,:),[0,-0.5,-1,-2,-3,-3.5,-4,-4.5,-5,-6,-16],...
		 'parent',data.axe2);
	axis(data.axe2,[x0-1 x1+1 0 tfinal]);
	h=colorbar('peer',data.axe2);
	set(h,'fontsize',7);
      end
    end
  end
end

if data.PlotFlag
  pl2(1:sav,:)=log10(abs(pl(1:sav,:)));
  contourf(x,tl(1:sav),pl2(1:sav,:),[0,-0.5,-1,-2,-3,-3.5,-4,-4.5,-5,-6,-16],...
	   'parent',data.axe2);
  axis(data.axe2,[x0-1 x1+1 0 tfinal]);
  h=colorbar('peer',data.axe2);
  set(h,'fontsize',7);
end
% Output
if data.ReturnFlag == 1
  out = pl;
elseif data.ReturnFlag == 2
  out.pl = pl;
  out.tl = tl;
  out.gridx = geo.x.';
else
  error(sprintf('Unknown ReturnFlag %g',ReturnFlag))
end


