function [A]=massMatrixPot(xl,xr,N,dx)
% Antoine-Besse July 2006
% Assembling of the finite element mass matrix
% for the potential term.
% Linear Finite Elements
% N : number of interior points
% dx : mesh size
% TBC on x0 and x1

% -------------------------------------------------------------------------
% The function f stands for the potential
f  = @(x) potential_func(x);

% -------------------------------------------------------------------------
% The following f function allows to verify that we have
% the good mass matrix if the potential equal one.
% f = @(x) 1;

% -------------------------------------------------------------------------
% The following f function allows to get a null potential.
% f=@(x) 0;

% -------------------------------------------------------------------------
% P1 finite element basis functions
g1 = @(x,k) -(x-k*dx)/dx;
g2 = @(x,k) (x-(k-1)*dx)/dx;

e=zeros(N+2,1);
A=spdiags([e,e,e],[-1:1],N+2,N+2);

% -------------------------------------------------------------------------
% Mass matrix
for j=1:N+1,
    % Elementary matrix
    f11 = @(x) f(x).*g1(x-xl,j).*g1(x-xl,j);
    f12 = @(x) f(x).*g1(x-xl,j).*g2(x-xl,j);
    f22 = @(x) f(x).*g2(x-xl,j).*g2(x-xl,j);
    El11=quad(f11,xl+(j-1)*dx,xl+j*dx);
    El12=quad(f12,xl+(j-1)*dx,xl+j*dx);
    El22=quad(f22,xl+(j-1)*dx,xl+j*dx);
    El1=[ El11 , El12; ...,
          El12 , El22];    
    A(j:j+1,j:j+1)=A(j:j+1,j:j+1)+El1;
end

